Using Bare Metal service as a standalone service
================================================

This guide explains how to configure and use the Bare Metal service standalone,
i.e. without other OpenStack services. In this mode users are interacting with
the bare metal API directly, not though OpenStack Compute.

.. toctree::
   :maxdepth: 3

   standalone/configure
   standalone/enrollment
   standalone/deploy
